{
    "$graph": [
        {
            "class": "Workflow",
            "id": "#main",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".64.amb",
                        ".64.ann",
                        ".64.bwt",
                        ".64.pac",
                        ".64.sa",
                        ".64.alt",
                        "^.dict"
                    ],
                    "id": "#main/indexed_reference_fasta"
                },
                {
                    "type": "File",
                    "id": "#main/input_rgbam"
                },
                {
                    "type": "string",
                    "id": "#main/sample_name"
                }
            ],
            "steps": [
                {
                    "run": "#bamtofastq_chomp.cwl",
                    "in": [
                        {
                            "source": "#main/input_rgbam",
                            "id": "#main/bamtofastq_chomp/input_bam"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/bamtofastq_chomp/sample"
                        }
                    ],
                    "out": [
                        "#main/bamtofastq_chomp/output",
                        "#main/bamtofastq_chomp/rg_string"
                    ],
                    "id": "#main/bamtofastq_chomp"
                },
                {
                    "run": "#bwa_mem_naive.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#main/bwa_mem_naive_bam/interleaved"
                        },
                        {
                            "source": "#main/bamtofastq_chomp/output",
                            "id": "#main/bwa_mem_naive_bam/reads"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/bwa_mem_naive_bam/ref"
                        },
                        {
                            "source": "#main/bamtofastq_chomp/rg_string",
                            "id": "#main/bwa_mem_naive_bam/rg"
                        }
                    ],
                    "scatter": [
                        "#main/bwa_mem_naive_bam/reads"
                    ],
                    "out": [
                        "#main/bwa_mem_naive_bam/output"
                    ],
                    "id": "#main/bwa_mem_naive_bam"
                }
            ],
            "hints": [
                {
                    "class": "https://sevenbridges.commaxNumberOfParallelInstances",
                    "value": 4
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/bwa_mem_naive_bam/output",
                    "id": "#main/unsorted_bams"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#bamtofastq_chomp.cwl",
            "doc": "If the input BAM is not provided the program will simply exit without failing.\nThis tool runs two programs:\n  - samtools view && biobambam2 bamtofastq\nThe program will first grab the RG header from the input BAM and put it in a file.\nThis RG header in the text file is later parsed into a string.\nNext it will convert the bam to fastq. If the file is over the max_size, it will\nchunk the output FASTQ into 680 million line FASTQs (85 million read pairs).",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 1000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/bwa-bundle:dev"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "/bin/bash",
                "-c"
            ],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "set -eo pipefail\n\nsamtools view -H $(inputs.input_bam.path) | grep ^@RG > rg.txt\n\nif [ $(inputs.input_bam.size) -gt $(inputs.max_size) ]; then\n  bamtofastq tryoq=1 filename=$(inputs.input_bam.path) | split -dl 680000000 - reads-\n  ls reads-* | xargs -i mv {} {}.fq\nelse\n  bamtofastq tryoq=1 filename=$(inputs.input_bam.path) > reads-00.fq\nfi"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "Input bam file",
                    "id": "#bamtofastq_chomp.cwl/bamtofastq_chomp/input_bam"
                },
                {
                    "type": "long",
                    "default": 20000000000,
                    "doc": "The maximum size (in bytes) that an input bam can be before the FASTQ is split",
                    "id": "#bamtofastq_chomp.cwl/bamtofastq_chomp/max_size"
                },
                {
                    "type": "string",
                    "doc": "String name of the sample used to relabel the rg string",
                    "id": "#bamtofastq_chomp.cwl/bamtofastq_chomp/sample"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.fq"
                    },
                    "id": "#bamtofastq_chomp.cwl/bamtofastq_chomp/output"
                },
                {
                    "type": "string",
                    "outputBinding": {
                        "glob": "rg.txt",
                        "loadContents": true,
                        "outputEval": "${ var arr = self[0].contents.split('\\n')[0].split('\\t'); for (var i=1; i<arr.length; i++){ if (arr[i].startsWith('SM')){ arr[i] = 'SM:' + inputs.sample; } } return arr.join('\\\\t'); }"
                    },
                    "id": "#bamtofastq_chomp.cwl/bamtofastq_chomp/rg_string"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#bwa_mem_naive.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 50000,
                    "coresMin": 36
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "zhangb1/bwa-kf-bundle:0.1.17"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "/bin/bash",
                "-c"
            ],
            "doc": "The program can handle the following classes of inputs:\n - single end reads (only reads File and rg string provided)\n - reads with mates (reads File, mates File, and rg string provided)\n - interleaved reads (reads File provided, rg string provided, and interleaved set to true)\nThis tool runs the following programs:\n - bwa mem | samblaster | sambamba view | sambamba sort",
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "set -eo pipefail\nbwa mem -K 100000000 ${if (inputs.interleaved) {return '-p';} else {return \"\"}} -v 3 -t 36 -Y $(inputs.ref.path) -R '${return inputs.rg}' ${return inputs.reads.path} ${if (inputs.mates != null) {return inputs.mates.path} else {return \"\"}} | /opt/samblaster/samblaster -i /dev/stdin -o /dev/stdout | /opt/sambamba_0.6.3/sambamba_v0.6.3 view -t 36 -f bam -l 0 -S /dev/stdin | /opt/sambamba_0.6.3/sambamba_v0.6.3 sort -t 36 --natural-sort -m 15GiB --tmpdir ./ -o ${if (inputs.reads != null) {return inputs.reads.nameroot} else {return \"\"}}.unsorted.bam -l 5 /dev/stdin"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "default": false,
                    "doc": "The reads input is interleaved",
                    "id": "#bwa_mem_naive.cwl/bwa_mem_naive/interleaved"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "Mates file for the reads",
                    "id": "#bwa_mem_naive.cwl/bwa_mem_naive/mates"
                },
                {
                    "type": "File",
                    "doc": "Primary reads file",
                    "id": "#bwa_mem_naive.cwl/bwa_mem_naive/reads"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".64.amb",
                        ".64.ann",
                        ".64.bwt",
                        ".64.pac",
                        ".64.sa",
                        ".64.alt",
                        "^.dict",
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        ".fai"
                    ],
                    "doc": "Reference fasta file with associated indexes",
                    "id": "#bwa_mem_naive.cwl/bwa_mem_naive/ref"
                },
                {
                    "type": "string",
                    "doc": "Formatted RG header to use in the resulting BAM, check BWA for formatting guidelines (e.g. escaped tabs '\\t')",
                    "id": "#bwa_mem_naive.cwl/bwa_mem_naive/rg"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.bam"
                    },
                    "id": "#bwa_mem_naive.cwl/bwa_mem_naive/output"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "sbg": "https://sevenbridges.com"
    }
}
